@@ -36,8 +36,6 @@
 #include <unistd.h>
 #endif
 
-#include <exo/exo.h>
-
 #include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4util/libxfce4util.h>
 #include <thunar-apr/thunar-apr-desktop-page.h>
@@ -539,7 +537,7 @@ thunar_apr_desktop_page_file_changed (ThunarAprAbstractPage *abstract_page,
 
       /* update the "Description" entry */
       value = g_key_file_get_locale_string (key_file, G_KEY_FILE_DESKTOP_GROUP, "GenericName", NULL, NULL);
-      if (!exo_str_is_equal (value, desktop_page->description_text))
+      if (g_strcmp0 (value, desktop_page->description_text) != 0)
         {
           /* update the entry */
           gtk_entry_set_text (GTK_ENTRY (desktop_page->description_entry), (value != NULL) ? value : "");
@@ -555,7 +553,7 @@ thunar_apr_desktop_page_file_changed (ThunarAprAbstractPage *abstract_page,
 
       /* update the "Comment" entry */
       value = g_key_file_get_locale_string (key_file, G_KEY_FILE_DESKTOP_GROUP, "Comment", NULL, NULL);
-      if (!exo_str_is_equal (value, desktop_page->comment_text))
+      if (g_strcmp0 (value, desktop_page->comment_text) != 0)
         {
           /* update the entry */
           gtk_entry_set_text (GTK_ENTRY (desktop_page->comment_entry), (value != NULL) ? value : "");
@@ -572,9 +570,9 @@ thunar_apr_desktop_page_file_changed (ThunarAprAbstractPage *abstract_page,
       /* update the type dependant entries */
       if (strcmp (type, "Application") == 0)
         {
-          /* update the "Command" entry */
-          value = g_key_file_get_string (key_file, G_KEY_FILE_DESKTOP_GROUP, "Exec", NULL);
-          if (!exo_str_is_equal (value, desktop_page->command_text))
+          /* update the "Command" entry but but ignore escape sequences */
+          value = g_key_file_get_value (key_file, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_EXEC, NULL);
+          if (g_strcmp0 (value, desktop_page->command_text) != 0)
             {
               /* update the entry */
               gtk_entry_set_text (GTK_ENTRY (desktop_page->command_entry), (value != NULL) ? value : "");
@@ -590,7 +588,7 @@ thunar_apr_desktop_page_file_changed (ThunarAprAbstractPage *abstract_page,
 
           /* update the "Path" entry */
           value = g_key_file_get_string (key_file, G_KEY_FILE_DESKTOP_GROUP, "Path", NULL);
-          if (!exo_str_is_equal (value, desktop_page->path_text))
+          if (g_strcmp0 (value, desktop_page->path_text) != 0)
             {
               /* update the entry */
               gtk_entry_set_text (GTK_ENTRY (desktop_page->path_entry), (value != NULL) ? value : "");
@@ -629,7 +627,7 @@ thunar_apr_desktop_page_file_changed (ThunarAprAbstractPage *abstract_page,
         {
           /* update the "URL" entry */
           value = g_key_file_get_string (key_file, G_KEY_FILE_DESKTOP_GROUP, "URL", NULL);
-          if (!exo_str_is_equal (value, desktop_page->url_text))
+          if (g_strcmp0 (value, desktop_page->url_text) != 0)
             {
               /* update the entry */
               gtk_entry_set_text (GTK_ENTRY (desktop_page->url_entry), (value != NULL) ? value : "");
@@ -840,17 +838,23 @@ thunar_apr_desktop_page_set_string (GKeyFile    *key_file,
                                     const gchar *key,
                                     const gchar *value)
 {
-  if (value != NULL && *value != '\0')
+  if (xfce_str_is_empty (value))
     {
-      g_key_file_set_string (key_file,
+      g_key_file_remove_key (key_file,
                              G_KEY_FILE_DESKTOP_GROUP,
-                             key, value);
+                             key, NULL);
     }
   else
     {
-      g_key_file_remove_key  (key_file,
+      /* escape special characters but not for the "Exec" property */
+      if (g_strcmp0 (key, G_KEY_FILE_DESKTOP_KEY_EXEC) == 0)
+        g_key_file_set_value (key_file,
                               G_KEY_FILE_DESKTOP_GROUP,
-                              key, NULL);
+                              key, value);
+      else
+        g_key_file_set_string (key_file,
+                               G_KEY_FILE_DESKTOP_GROUP,
+                               key, value);
     }
 }
 
