@@ -652,8 +652,8 @@ thunar_application_load_css (void)
   css_provider = gtk_css_provider_new ();
 
   gtk_css_provider_load_from_data (css_provider,
-    /* for the pathbar-buttons any margin looks ugly*/
-    ".path-bar-button { margin-right: 0; }"
+    /* for the location-buttons any margin looks ugly */
+    ".location-button { margin-right: 0; }"
     /* remove extra border between side pane and view */
     ".shortcuts-pane { border-right-width: 0px; }"
     /* add missing top border to side pane */
@@ -1523,7 +1523,7 @@ thunar_application_bulk_rename (ThunarApplication *application,
   for (n = 0; filenames[n] != NULL; ++n)
     {
       /* check if the filename is an absolute path or looks like an URI */
-      if (g_path_is_absolute (filenames[n]) || exo_str_looks_like_an_uri (filenames[n]))
+      if (g_path_is_absolute (filenames[n]) || g_uri_is_valid (filenames[n], G_URI_FLAGS_NONE, NULL))
         {
           /* determine the file for the filename directly */
           file = thunar_file_get_for_uri (filenames[n], error);
@@ -1751,7 +1751,7 @@ thunar_application_process_filenames (ThunarApplication               *applicati
   for (n = 0; filenames[n] != NULL; ++n)
     {
       /* check if the filename is an absolute path or looks like an URI */
-      if (g_path_is_absolute (filenames[n]) || exo_str_looks_like_an_uri (filenames[n]))
+      if (g_path_is_absolute (filenames[n]) || g_uri_is_valid (filenames[n], G_URI_FLAGS_NONE, NULL))
         {
           /* determine the file for the filename directly */
           file = thunar_file_get_for_uri (filenames[n], &derror);
@@ -2090,18 +2090,25 @@ thunar_application_copy_into (ThunarApplication *application,
                               GFile             *target_file,
                               GClosure          *new_files_closure)
 {
-  GVolume *volume         = NULL;
-  gchar   *display_name   = NULL;
-  gchar   *title          = NULL;
-  gchar   *volume_name    = NULL;
-  gchar   *volume_uuid    = NULL;
-  gboolean use_display_name;
+  ThunarFile *target_folder;
+  GVolume    *volume         = NULL;
+  gchar      *display_name   = NULL;
+  gchar      *title          = NULL;
+  gchar      *volume_name    = NULL;
+  gchar      *volume_uuid    = NULL;
+  gboolean    use_display_name;
 
   _thunar_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
   _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
   _thunar_return_if_fail (G_IS_FILE (target_file));
 
-  volume = thunar_file_get_volume (thunar_file_get_for_uri (g_file_get_uri (target_file), NULL));
+  target_folder = thunar_file_get (target_file , NULL);
+  if (target_folder != NULL)
+    {
+      volume = thunar_file_get_volume (target_folder);
+      g_object_unref (target_folder);
+    }
+
   if (volume != NULL)
     {
       volume_name = g_volume_get_name (volume);
