@@ -235,6 +235,25 @@ typedef enum
 GType thunar_recursive_permissions_get_type (void) G_GNUC_CONST;
 
 
+#define THUNAR_TYPE_RECURSIVE_SEARCH (thunar_recursive_search_get_type ())
+
+/**
+ * ThunarRecursiveSearchMode:
+ * @THUNAR_RECURSIVE_SEARCH_LOCAL       : do recursive search only locally.
+ * @THUNAR_RECURSIVE_SEARCH_ALWAYS      : always do recursive search.
+ * @THUNAR_RECURSIVE_SEARCH_NEVER       : never do recursive search.
+ *
+ **/
+typedef enum
+{
+  THUNAR_RECURSIVE_SEARCH_LOCAL,
+  THUNAR_RECURSIVE_SEARCH_ALWAYS,
+  THUNAR_RECURSIVE_SEARCH_NEVER,
+} ThunarRecursiveSearchMode;
+
+GType thunar_recursive_search_get_type (void) G_GNUC_CONST;
+
+
 #define THUNAR_TYPE_ZOOM_LEVEL (thunar_zoom_level_get_type ())
 
 /**
@@ -398,6 +417,7 @@ typedef enum
     THUNAR_STATUS_BAR_INFO_SIZE_IN_BYTES  = 1 << 1,
     THUNAR_STATUS_BAR_INFO_FILETYPE       = 1 << 2,
     THUNAR_STATUS_BAR_INFO_DISPLAY_NAME   = 1 << 3,
+    THUNAR_STATUS_BAR_INFO_LAST_MODIFIED  = 1 << 4,
 } ThunarStatusBarInfo;
 
 guint    thunar_status_bar_info_toggle_bit    (guint               info,
