@@ -148,6 +148,61 @@ thunar_g_file_new_for_bookmarks (void)
 
 
 
+/**
+ * thunar_g_file_new_for_symlink_target:
+ * @file : a #GFile.
+ *
+ * Returns the symlink target of @file as a GFile.
+ *
+ * Return value: (nullable) (transfer full): A #GFile on success and %NULL on failure.
+ **/
+GFile *
+thunar_g_file_new_for_symlink_target (GFile *file)
+{
+  const gchar *target_path;
+  gchar       *file_path;
+  GFile       *file_parent = NULL;
+  GFile       *target_gfile = NULL;
+  GFileInfo   *info = NULL;
+  GError      *error = NULL;
+
+  _thunar_return_val_if_fail (G_IS_FILE (file), NULL);
+
+  /* Intialise the GFileInfo for querying symlink target */
+  info = g_file_query_info (file,
+                            G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET,
+                            G_FILE_QUERY_INFO_NONE,
+                            NULL, &error);
+
+  if (info == NULL)
+    {
+      file_path = g_file_get_path (file);
+      g_warning ("Symlink target loading failed for %s: %s",
+                 file_path,
+                 error->message);
+      g_free (file_path);
+      g_error_free (error);
+      return NULL;
+    }
+
+  target_path = g_file_info_get_symlink_target (info);
+  file_parent = g_file_get_parent (file);
+
+  /* if target_path is an absolute path, the target_gfile is created using only the target_path
+  ** else if target_path is relative then it is resolved with respect to the parent of the symlink (@file) */
+  if (G_LIKELY (target_path != NULL && file_parent != NULL))
+    target_gfile = g_file_resolve_relative_path (file_parent, target_path);
+
+  /* free allocated resources */
+  if (G_LIKELY (file_parent != NULL))
+    g_object_unref (file_parent);
+  g_object_unref (info);
+
+  return target_gfile;
+}
+
+
+
 gboolean
 thunar_g_file_is_root (GFile *file)
 {
@@ -1109,3 +1164,70 @@ thunar_g_vfs_metadata_is_supported (void)
 
   return metadata_is_supported;
 }
+
+
+
+/**
+ * thunar_g_file_is_on_local_device:
+ * @file : the source or target #GFile to test.
+ *
+ * Tries to find if the @file is on a local device or not.
+ * Local device if (all conditions should match):
+ * - the file has a 'file' uri scheme.
+ * - the file is located on devices not handled by the #GVolumeMonitor (GVFS).
+ * - the device is handled by #GVolumeMonitor (GVFS) and cannot be unmounted
+ *   (USB key/disk, fuse mounts, Samba shares, PTP devices).
+ *
+ * The target @file may not exist yet when this function is used, so recurse
+ * the parent directory, possibly reaching the root mountpoint.
+ *
+ * This should be enough to determine if a @file is on a local device or not.
+ *
+ * Return value: %TRUE if #GFile @file is on a so-called local device.
+ **/
+gboolean
+thunar_g_file_is_on_local_device (GFile *file)
+{
+  gboolean  is_local = FALSE;
+  GFile    *target_file;
+  GFile    *target_parent;
+  GMount   *file_mount;
+
+  _thunar_return_val_if_fail (file != NULL, TRUE);
+  _thunar_return_val_if_fail (G_IS_FILE (file), TRUE);
+
+  if (g_file_has_uri_scheme (file, "file") == FALSE)
+    return FALSE;
+  for (target_file  = g_object_ref (file);
+       target_file != NULL;
+       target_file  = target_parent)
+    {
+      if (g_file_query_exists (target_file, NULL))
+        break;
+
+      /* file or parent directory does not exist (yet)
+       * query the parent directory */
+      target_parent = g_file_get_parent (target_file);
+      g_object_unref (target_file);
+    }
+
+  if (target_file == NULL)
+    return FALSE;
+
+  /* file_mount will be NULL for local files on local partitions/devices */
+  file_mount = g_file_find_enclosing_mount (target_file, NULL, NULL);
+  g_object_unref (target_file);
+  if (file_mount == NULL)
+    is_local = TRUE;
+  else
+    {
+      /* mountpoints which cannot be unmounted are local devices.
+       * attached devices like USB key/disk, fuse mounts, Samba shares,
+       * PTP devices can always be unmounted and are considered remote/slow. */
+      is_local = ! g_mount_can_unmount (file_mount);
+      g_object_unref (file_mount);
+    }
+
+  return is_local;
+}
+
