@@ -38,13 +38,15 @@ struct _ThunarLocationBarClass
 
   /* signals */
   void (*entry_done) (void);
-  void (*reload_requested) (void);
+  void (*reload_requested) (void); /* UNUSED */
 };
 
 struct _ThunarLocationBar
 {
   GtkBin __parent__;
 
+  ThunarPreferences *preferences;
+
   ThunarFile *current_directory;
 
   GtkWidget  *locationEntry;
@@ -105,7 +107,7 @@ thunar_location_bar_class_init (ThunarLocationBarClass *klass)
   gobject_class->set_property = thunar_location_bar_set_property;
   gobject_class->finalize = thunar_location_bar_finalize;
 
-  klass->reload_requested = exo_noop;
+  klass->reload_requested = NULL;
 
   /* Override ThunarNavigator's properties */
   g_object_class_override_property (gobject_class, PROP_CURRENT_DIRECTORY, "current-directory");
@@ -133,7 +135,7 @@ thunar_location_bar_class_init (ThunarLocationBarClass *klass)
 static void
 thunar_location_bar_init (ThunarLocationBar *bar)
 {
-  ThunarPreferences *preferences = thunar_preferences_get ();
+  bar->preferences = thunar_preferences_get ();
 
   bar->current_directory = NULL;
   bar->locationEntry = NULL;
@@ -141,7 +143,7 @@ thunar_location_bar_init (ThunarLocationBar *bar)
 
   thunar_location_bar_settings_changed (bar);
 
-  g_signal_connect_object (preferences, "notify::last-location-bar", G_CALLBACK (thunar_location_bar_settings_changed), bar, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (bar->preferences, "notify::last-location-bar", G_CALLBACK (thunar_location_bar_settings_changed), bar);
 }
 
 
@@ -153,6 +155,10 @@ thunar_location_bar_finalize (GObject *object)
 
   _thunar_return_if_fail (THUNAR_IS_LOCATION_BAR (bar));
 
+  /* disconnect from the preferences */
+  g_signal_handlers_disconnect_by_func (bar->preferences, thunar_location_bar_settings_changed, bar);
+  g_object_unref (bar->preferences);
+
   if (bar->locationEntry)
     g_object_unref (bar->locationEntry);
   if (bar->locationButtons)
@@ -345,7 +351,7 @@ thunar_location_bar_settings_changed (ThunarLocationBar *bar)
   gchar *last_location_bar;
   GType  type;
 
-  g_object_get (thunar_preferences_get(), "last-location-bar", &last_location_bar, NULL);
+  g_object_get (bar->preferences, "last-location-bar", &last_location_bar, NULL);
 
   /* validate it */
   if (!strcmp (last_location_bar, g_type_name (THUNAR_TYPE_LOCATION_BUTTONS)))
