@@ -65,6 +65,7 @@ typedef enum
   THUNAR_MENU_SECTION_PROPERTIES          = 1 << 13,
   THUNAR_MENU_SECTION_MOUNTABLE           = 1 << 14,
   THUNAR_MENU_SECTION_REMOVE_FROM_RECENT  = 1 << 15,
+  THUNAR_MENU_SECTION_EDIT_LAUNCHER       = 1 << 16,
 
 } ThunarMenuSections;
 
@@ -73,8 +74,7 @@ GType      thunar_menu_get_type          (void) G_GNUC_CONST;
 
 gboolean   thunar_menu_add_sections      (ThunarMenu         *menu,
                                           ThunarMenuSections  menu_sections);
-GtkWidget* thunar_menu_get_launcher      (ThunarMenu         *menu);
-void       thunar_menu_hide_accel_labels (ThunarMenu         *menu);
+GtkWidget* thunar_menu_get_action_manager(ThunarMenu         *menu);
 
 G_END_DECLS;
 
