@@ -95,6 +95,7 @@ enum
   PROP_MISC_MIDDLE_CLICK_IN_TAB,
   PROP_MISC_OPEN_NEW_WINDOW_AS_TAB,
   PROP_MISC_RECURSIVE_PERMISSIONS,
+  PROP_MISC_RECURSIVE_SEARCH,
   PROP_MISC_REMEMBER_GEOMETRY,
   PROP_MISC_SHOW_ABOUT_TEMPLATES,
   PROP_MISC_SHOW_DELETE_ACTION,
@@ -119,6 +120,7 @@ enum
   PROP_TREE_ICON_SIZE,
   PROP_MISC_SWITCH_TO_NEW_TAB,
   PROP_MISC_VERTICAL_SPLIT_PANE,
+  PROP_MISC_COMPACT_VIEW_MAX_CHARS,
   N_PROPERTIES,
 };
 
@@ -447,7 +449,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
         g_param_spec_string ("last-toolbar-visible-buttons",
                              "LastToolbarVisibleButtons",
                              NULL,
-                             "1,1,1,1,0,0,0,1,0,1",
+                             "0,1,1,1,1,0,0,0,0,0,0,1,0,1",
                              EXO_PARAM_READWRITE);
 
   /**
@@ -459,7 +461,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
         g_param_spec_string ("last-toolbar-item-order",
                              "LastToolbarButtonOrder",
                              NULL,
-                             "0,1,2,3,4,5,6,7,8,9",
+                             "0,1,2,3,4,5,6,7,8,9,10,11,12,13",
                              EXO_PARAM_READWRITE);
 
   /**
@@ -759,6 +761,19 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          THUNAR_RECURSIVE_PERMISSIONS_ASK,
                          EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:misc-recursive-search:
+   *
+   * Whether to search only in the current folder or recursively
+  **/
+  preferences_props[PROP_MISC_RECURSIVE_SEARCH] =
+       g_param_spec_enum ("misc-recursive-search",
+                          "MiscRecursiveSearch",
+                          NULL,
+                          THUNAR_TYPE_RECURSIVE_SEARCH,
+                          THUNAR_RECURSIVE_SEARCH_ALWAYS,
+                          EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:misc-remember-geometry:
    *
@@ -1077,6 +1092,19 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                           FALSE,
                           EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:compact-view-max-chars
+   *
+   * The ellipsization threshold for compact view. Negative values disable ellipsization.
+   **/
+  preferences_props[PROP_MISC_COMPACT_VIEW_MAX_CHARS] =
+      g_param_spec_int ("misc-compact-view-max-chars",
+                        "MiscCompactViewMaxChars",
+                        NULL,
+                        G_MININT, G_MAXINT,
+                        50,
+                        EXO_PARAM_READWRITE);
+
   /* install all properties */
   g_object_class_install_properties (gobject_class, N_PROPERTIES, preferences_props);
 }
