@@ -182,7 +182,7 @@ struct _ThunarTreeViewClass
 
 struct _ThunarTreeView
 {
-  GtkTreeView              __parent__;
+  GtkTreeView             __parent__;
   ThunarClipboardManager *clipboard;
   ThunarPreferences      *preferences;
   GtkCellRenderer        *icon_renderer;
@@ -205,7 +205,7 @@ struct _ThunarTreeView
   GtkTreePath            *select_path;
 
   /* used to create menu items for the context menu */
-  ThunarLauncher         *launcher;
+  ThunarActionManager    *action_mgr;
 
   /* the currently pressed mouse button, set in the
    * button-press-event handler if the associated
@@ -351,7 +351,7 @@ thunar_tree_view_init (ThunarTreeView *view)
   view->model = g_object_new (THUNAR_TYPE_TREE_MODEL, NULL);
 
   /* synchronize the the global "misc-case-sensitive" preference */
-  g_object_set_data_full (G_OBJECT (view->model), I_("thunar-preferences"), view->preferences, g_object_unref);
+  g_object_set_data (G_OBJECT (view->model), I_("thunar-preferences"), view->preferences);
   g_object_bind_property (G_OBJECT (view->preferences), "misc-case-sensitive", G_OBJECT (view->model), "case-sensitive", G_BINDING_SYNC_CREATE);
 
   thunar_tree_model_set_visible_func (view->model, thunar_tree_view_visible_func, view);
@@ -408,12 +408,12 @@ thunar_tree_view_init (ThunarTreeView *view)
   gtk_drag_dest_set (GTK_WIDGET (view), 0, drop_targets, G_N_ELEMENTS (drop_targets),
                      GDK_ACTION_COPY | GDK_ACTION_LINK | GDK_ACTION_MOVE);
 
-  view->launcher =  g_object_new (THUNAR_TYPE_LAUNCHER, "widget", GTK_WIDGET (view), NULL);
+  view->action_mgr =  g_object_new (THUNAR_TYPE_ACTION_MANAGER, "widget", GTK_WIDGET (view), NULL);
 
-  g_signal_connect_swapped (G_OBJECT (view->launcher), "change-directory", G_CALLBACK (thunar_tree_view_action_open), view);
-  g_signal_connect_swapped (G_OBJECT (view->launcher), "open-new-tab", G_CALLBACK (thunar_navigator_open_new_tab), view);
-  g_signal_connect_swapped (G_OBJECT (view->launcher), "new-files-created", G_CALLBACK (thunar_tree_view_select_files), view);
-  g_object_bind_property (G_OBJECT (view), "current-directory", G_OBJECT (view->launcher), "current-directory", G_BINDING_SYNC_CREATE);
+  g_signal_connect_swapped (G_OBJECT (view->action_mgr), "change-directory", G_CALLBACK (thunar_tree_view_action_open), view);
+  g_signal_connect_swapped (G_OBJECT (view->action_mgr), "open-new-tab", G_CALLBACK (thunar_navigator_open_new_tab), view);
+  g_signal_connect_swapped (G_OBJECT (view->action_mgr), "new-files-created", G_CALLBACK (thunar_tree_view_select_files), view);
+  g_object_bind_property (G_OBJECT (view), "current-directory", G_OBJECT (view->action_mgr), "current-directory", G_BINDING_SYNC_CREATE);
 }
 
 
@@ -451,8 +451,8 @@ thunar_tree_view_finalize (GObject *object)
   /* reset the current-directory property */
   thunar_navigator_set_current_directory (THUNAR_NAVIGATOR (view), NULL);
 
-  /* release reference on the launcher */
-  g_object_unref (view->launcher);
+  /* release reference on the action manager */
+  g_object_unref (view->action_mgr);
 
   /* release our reference on the preferences */
   g_object_unref (G_OBJECT (view->preferences));
@@ -770,16 +770,20 @@ thunar_tree_view_button_release_event (GtkWidget      *widget,
           ThunarFile *file  = thunar_tree_view_get_selected_file (view);
           GList      *files = NULL;
 
-          g_object_get (view->preferences, "misc-middle-click-in-tab", &in_tab, NULL);
+          if (file != NULL)
+            {
+              g_object_get (view->preferences, "misc-middle-click-in-tab", &in_tab, NULL);
 
-          /* holding ctrl inverts the action */
-          if ((event->state & GDK_CONTROL_MASK) != 0)
-            in_tab = !in_tab;
+              /* holding ctrl inverts the action */
+              if ((event->state & GDK_CONTROL_MASK) != 0)
+                in_tab = !in_tab;
 
-          files = g_list_append (files, file);
-          thunar_launcher_set_selection (view->launcher, files, NULL, NULL);
-          thunar_launcher_open_selected_folders (view->launcher, in_tab);
-          g_list_free (files);
+              files = g_list_append (files, file);
+              thunar_action_manager_set_selection (view->action_mgr, files, NULL, NULL);
+              thunar_action_manager_open_selected_folders (view->action_mgr, in_tab);
+              g_list_free (files);
+              g_object_unref (file);
+            }
 
           /* set the cursor back to the previously selected item */
           if (view->select_path != NULL)
@@ -855,8 +859,8 @@ thunar_tree_view_key_press_event(GtkWidget   *widget,
                 {
                   /* mark this path for selection after unmounting */
                   view->select_path = gtk_tree_path_copy(path);
-                  g_object_set (G_OBJECT (view->launcher), "selected-device", device, NULL);
-                  thunar_launcher_action_unmount (view->launcher);
+                  g_object_set (G_OBJECT (view->action_mgr), "selected-device", device, NULL);
+                  thunar_action_manager_action_unmount (view->action_mgr);
                   g_object_unref (G_OBJECT (device));
                 }
           }
@@ -873,8 +877,8 @@ thunar_tree_view_key_press_event(GtkWidget   *widget,
                             THUNAR_TREE_MODEL_COLUMN_DEVICE, &device, -1);
      if (device != NULL && thunar_device_is_mounted (device) == FALSE)
        {
-         g_object_set (G_OBJECT (view->launcher), "selected-device", device, NULL);
-         thunar_launcher_action_mount (view->launcher);
+         g_object_set (G_OBJECT (view->action_mgr), "selected-device", device, NULL);
+         thunar_action_manager_action_mount (view->action_mgr);
        }
      else
        {
@@ -1155,9 +1159,9 @@ thunar_tree_view_test_expand_row (GtkTreeView *tree_view,
         {
           /* we need to mount the device before we can expand the row */
           expandable = FALSE;
-          g_object_set (G_OBJECT (view->launcher), "selected-device", device, NULL);
+          g_object_set (G_OBJECT (view->action_mgr), "selected-device", device, NULL);
           /* The closure will expand the row after the mount operation finished */
-          thunar_launcher_action_mount (view->launcher);
+          thunar_action_manager_action_mount (view->action_mgr);
         }
 
       /* release the device */
@@ -1235,24 +1239,24 @@ thunar_tree_view_context_menu (ThunarTreeView *view,
                       -1);
 
   context_menu = g_object_new (THUNAR_TYPE_MENU, "menu-type", THUNAR_MENU_TYPE_CONTEXT_TREE_VIEW,
-                                                 "launcher", view->launcher,
+                                                 "action_mgr", view->action_mgr,
                                                  "force-section-open", TRUE, NULL);
 
   file_is_available = (device == NULL || thunar_device_is_mounted (device));
   if (file_is_available)
     {
       files = g_list_append (NULL, file);
-      g_object_set (G_OBJECT (view->launcher), "current-directory", view->current_directory, NULL);
-      thunar_launcher_set_selection (view->launcher, files, device, NULL);
+      g_object_set (G_OBJECT (view->action_mgr), "current-directory", view->current_directory, NULL);
+      thunar_action_manager_set_selection (view->action_mgr, files, device, NULL);
       g_list_free (files);
 
       if(thunar_g_file_is_trash    (thunar_file_get_file (file)) ||
          thunar_g_file_is_computer (thunar_file_get_file (file)) ||
          thunar_g_file_is_network  (thunar_file_get_file (file)))
         {
-          thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN, TRUE);
-          thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_TAB, TRUE);
-          thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_WINDOW, TRUE);
+          thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN, TRUE);
+          thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_TAB, TRUE);
+          thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_WINDOW, TRUE);
           xfce_gtk_menu_append_separator (GTK_MENU_SHELL (context_menu));
           thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_EMPTY_TRASH);
         }
@@ -1273,17 +1277,17 @@ thunar_tree_view_context_menu (ThunarTreeView *view,
     }
   else
     {
-      g_object_set (G_OBJECT (view->launcher), "selected-device", device, NULL);
-      thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN, TRUE);
-      thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_TAB, TRUE);
-      thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_WINDOW, TRUE);
+      g_object_set (G_OBJECT (view->action_mgr), "selected-device", device, NULL);
+      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN, TRUE);
+      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_TAB, TRUE);
+      thunar_action_manager_append_menu_item (view->action_mgr, GTK_MENU_SHELL (context_menu), THUNAR_ACTION_MANAGER_ACTION_OPEN_IN_WINDOW, TRUE);
       xfce_gtk_menu_append_separator (GTK_MENU_SHELL (context_menu));
       thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_MOUNTABLE);
       if (thunar_device_is_mounted (device))
         thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_PROPERTIES);
     }
 
-  thunar_menu_hide_accel_labels (context_menu);
+  thunar_gtk_menu_hide_accel_labels (GTK_MENU (context_menu));
   gtk_widget_show_all (GTK_WIDGET (context_menu));
   window = gtk_widget_get_toplevel (GTK_WIDGET (view));
   thunar_window_redirect_menu_tooltips_to_statusbar (THUNAR_WINDOW (window), GTK_MENU (context_menu));
@@ -1377,6 +1381,15 @@ thunar_tree_view_get_dest_actions (ThunarTreeView *view,
 
 
 
+/**
+ * thunar_tree_view_get_selected_file:
+ * @view : a #ThunarTreeView instance.
+ *
+ * Returns the selected #ThunarFile, or %NULL if no valid selection was found.
+ * The caller is responsible to call g_object_unref() on the #ThunarFile after usage.
+ *
+ * Return value: (nullable) (transfer full): The selected #ThunarFile or %NULL.
+ **/
 static ThunarFile*
 thunar_tree_view_get_selected_file (ThunarTreeView *view)
 {
@@ -1484,8 +1497,8 @@ thunar_tree_view_action_open (ThunarTreeView *view)
         thunar_tree_view_open_selection (view);
       else
       {
-        g_object_set (G_OBJECT (view->launcher), "selected-device", device, NULL);
-        thunar_launcher_action_mount (view->launcher);
+        g_object_set (G_OBJECT (view->action_mgr), "selected-device", device, NULL);
+        thunar_action_manager_action_mount (view->action_mgr);
       }
     }
   else if (file != NULL)
